===========
Plot module
===========

Functions for plotting graphs and graph properties.


Content
=======

.. autosummary::

    nngt.plot.Animation2d
    nngt.plot.AnimationNetwork
    nngt.plot.betweenness_distribution
    nngt.plot.compare_population_attributes
    nngt.plot.correlation_to_attribute
    nngt.plot.degree_distribution
    nngt.plot.draw_network
    nngt.plot.edge_attributes_distribution
    nngt.plot.node_attributes_distribution
    nngt.plot.palette


Details
=======

.. automodule:: nngt.plot
    :show-inheritance:
    :inherited-members:
